## Sid Meier's Civilization 4
## Copyright Firaxis Games 2005
## 
## CvAoDEventManager
## This class is passed an argsList from CvAppInterface.onEvent
## The argsList can contain anything from mouse location to key info
## The EVENTLIST that are being notified can be found 


from CvPythonExtensions import *
import CvUtil
import CvScreensInterface
import CvDebugTools
import CvWBPopups
import PyHelpers
import Popup as PyPopup
import CvCameraControls
import CvTopCivs
import CvEventManager
import sys
	
gc = CyGlobalContext()
localText = CyTranslator()
PyPlayer = PyHelpers.PyPlayer
PyInfo = PyHelpers.PyInfo
DefaultUnitAI = UnitAITypes.NO_UNITAI

# The main bits
###################################################
class CvAoDEventManager(CvEventManager.CvEventManager):
	def __init__(self):
		# initialize base class
		self.parent = CvEventManager.CvEventManager
		self.parent.__init__(self)

	def onGameStart(self, argsList):
                # initialise player IDs
		self.iEnglandID = 0
		self.iFranceID = 1
		self.iSpainID = 2
		self.iPortugalID = 5
		self.iHollandID = 7
		self.iScotlandID = 10
		self.iSaxonyID = 3
		self.iGenoaID = 4
		self.iArabID = 6
		self.iMayaID = 8
		self.iAztecID = 9
		self.iNumPlayers = 11

                # initialise unit IDs
		self.iCaravelID = CvUtil.findInfoTypeNum(gc.getUnitInfo,gc.getNumUnitInfos(),'UNIT_CARAVEL')
		self.iPikemanID = CvUtil.findInfoTypeNum(gc.getUnitInfo,gc.getNumUnitInfos(),'UNIT_PIKEMAN')
		self.iSettlerID = CvUtil.findInfoTypeNum(gc.getUnitInfo,gc.getNumUnitInfos(),'UNIT_SETTLER')

		# display welcome message
		for iPlayer in range(gc.getMAX_PLAYERS()):
			player = gc.getPlayer(iPlayer)
			if (player.isAlive() and player.isHuman()):
				popupInfo = CyPopupInfo()
				popupInfo.setButtonPopupType(ButtonPopupTypes.BUTTONPOPUP_PYTHON_SCREEN)
				popupInfo.setText(u"showDawnOfMan")
				popupInfo.addPopup(iPlayer)
		
	def onBeginGameTurn(self, argsList):
		iGameTurn = argsList[0]
		
		# Age of Discovery events
		self.turnChecker(iGameTurn)

# AoD Events
###################################################

	def turnChecker(self, iTurn):
		
		# Setup players for use in this function
		pEngland = gc.getPlayer(self.iEnglandID)
		pFrance = gc.getPlayer(self.iFranceID)
		pSpain = gc.getPlayer(self.iSpainID)
		pPortagal = gc.getPlayer(self.iPortugalID)
		pHolland = gc.getPlayer(self.iHollandID)
		
		# Helper every 20 turns on average
		iRndNum = gc.getGame().getSorenRandNum(100, 'AoD - Random Event Start')
		if iRndNum < 5:			# 5% chance
                    if iTurn > 1 and iTurn < 150:
                        if (not pEngland.isHuman() and pEngland.isAlive()):
                            pEngland.initUnit(self.iCaravelID, 92, 51, UnitAITypes.UNITAI_SETTLER_SEA)
                            pEngland.initUnit(self.iPikemanID, 92, 51, UnitAITypes.UNITAI_COUNTER)
                            pEngland.initUnit(self.iSettlerID, 92, 51, UnitAITypes.UNITAI_SETTLE)
                        if (not pFrance.isHuman() and pFrance.isAlive()):
                            pFrance.initUnit(self.iCaravelID, 88, 47, UnitAITypes.UNITAI_SETTLER_SEA)
                            pFrance.initUnit(self.iPikemanID, 88, 47, UnitAITypes.UNITAI_COUNTER)
                            pFrance.initUnit(self.iSettlerID, 88, 47, UnitAITypes.UNITAI_SETTLE)
                        if (not pSpain.isHuman() and pSpain.isAlive()):
                            pSpain.initUnit(self.iCaravelID, 77, 26, UnitAITypes.UNITAI_SETTLER_SEA)
                            pSpain.initUnit(self.iPikemanID, 77, 26, UnitAITypes.UNITAI_COUNTER)
                            pSpain.initUnit(self.iSettlerID, 77, 26, UnitAITypes.UNITAI_SETTLE)
                        if (not pPortagal.isHuman() and pPortagal.isAlive()):
                            pPortagal.initUnit(self.iCaravelID, 75, 31, UnitAITypes.UNITAI_SETTLER_SEA)
                            pPortagal.initUnit(self.iPikemanID, 75, 31, UnitAITypes.UNITAI_COUNTER)
                            pPortagal.initUnit(self.iSettlerID, 75, 31, UnitAITypes.UNITAI_SETTLE)
                        if (not pHolland.isHuman() and pHolland.isAlive()):
                            pHolland.initUnit(self.iCaravelID, 103, 54, UnitAITypes.UNITAI_SETTLER_SEA)
                            pHolland.initUnit(self.iPikemanID, 103, 54, UnitAITypes.UNITAI_COUNTER)
                            pHolland.initUnit(self.iSettlerID, 103, 54, UnitAITypes.UNITAI_SETTLE)
			
		# Insert all game turn events here
#		print("Turn is: %d" %(iTurn))
#		if (iTurn == 4 + self.iTurnOffset):
#			self.Nov_1775()
#		elif (iTurn == 6 + self.iTurnOffset):
#			self.Jan_1776()

# AoD Utilities
###################################################
                
